@@ -7,8 +7,9 @@ use PRANG::Graph;
 with 'XML::SRS::TimeStamp::Role', 'XML::SRS::Node';
 
 use Moose::Util::TypeConstraints;
-use MooseX::Timestamp;
-use MooseX::TimestampTZ;
+use MooseX::Timestamp qw();
+use MooseX::TimestampTZ qw();
+use XML::SRS::Types;
 
 coerce __PACKAGE__
 	=> from Timestamp
@@ -22,13 +23,18 @@ coerce __PACKAGE__
 		__PACKAGE__->new(timestamptz => $_);
 	};
 
+coerce __PACKAGE__
+	=> from "Str"
+	=> via {
+		__PACKAGE__->new(timestamptz => $_);
+	};
+
 coerce __PACKAGE__
 	=> from "Int"
 	=> via {
 		__PACKAGE__->new(epoch => $_);
 	};
 
-
 sub BUILDARGS {
 	my $class = shift;
 	my %args = @_;
